Export Package VRC : bcB61Ma cn30
Update compared VRC:   B61 a cn30
Only Package       : Yes
Based on sessions  : No
Script sources     : No
Function  sources  : Yes
Library sources    : No
Creation Date      : 030714 11:11:42
Total file size    : 591356
---------------------------------------
C = Charts
q = Questions
c = Messages
l = Labels
d = Domains
t = Table Definitions
s = Sessions
p = Scripts
o = Objects
f = Forms
F = Form Dumps
m = Menus
M = Menu Dumps
r = Reports
i = Impl. Functions
S = Subscription Templates
b = Functions
A = Additional Files
h = Help Text Codes
Q = SQL Queries
P = Customization Projects
----------------------
sbccnv5200m000                                        B61Ma cn30 (not expired)
sbcdmp4220m000                                        B61Ma cn30 (not expired)
sbcdmp9087m000                                        B61Ma cn30 (not expired)
sbcdmp9188m000                                        B61Ma cn30 (not expired)
sbcgct0100m000                                        B61Ma cn30 (not expired)
sbcgct8189m000                                        B61Ma cn30 (not expired)
sbcgcteasym000                                        B61Ma cn30 (not expired)
pbccnv5200                                            B61Ma cn30 (without source) (not expired)
pbccnv5201                                            B61Ma cn30 (without source) (not expired)
pbcdmp000                                             B61Ma cn30 (without source) (not expired)
pbcdmp0100                                            B61Ma cn30 (without source) (not expired)
pbcdmp9087                                            B61Ma cn30 (without source) (not expired)
pbcdmp9188                                            B61Ma cn30 (without source) (not expired)
pbcdmpdllcommon                                       B61Ma cn30 (without source) (not expired)
pbcgct000                                             B61Ma cn30 (without source) (not expired)
pbcgct0100                                            B61Ma cn30 (without source) (not expired)
pbcgct8189                                            B61Ma cn30 (without source) (not expired)
pbcgct8289                                            B61Ma cn30 (without source) (not expired)
pbcgct9188                                            B61Ma cn30 (without source) (not expired)
pbcgcteasy                                            B61Ma cn30 (without source) (not expired)
pbcgenntdll                                           B61Ma cn30 (without source) (not expired)
pbcrun8288                                            B61Ma cn30 (without source) (not expired)
pbcrun90502                                           B61Ma cn30 (without source) (not expired)
pbcrun90506                                           B61Ma cn30 (without source) (not expired)
pbcrun90507                                           B61Ma cn30 (without source) (not expired)
pbcruncommon                                          B61Ma cn30 (without source) (not expired)
pbcrunconvdll                                         B61Ma cn30 (without source) (not expired)
pbcrundalload                                         B61Ma cn30 (without source) (not expired)
pbcrundll0200                                         B61Ma cn30 (without source) (not expired)
pbcrundllcommon                                       B61Ma cn30 (without source) (not expired)
fbccnv5200m000d2                                      B61Ma cn30 (not expired)
fbcdmp4220m000d2                                      B61Ma cn30 (not expired)
fbcdmp9087m000d2                                      B61Ma cn30 (not expired)
fbcdmp9188m000d2                                      B61Ma cn30 (not expired)
fbcgct0100m000d2                                      B61Ma cn30 (not expired)
fbcgct8189m000d2                                      B61Ma cn30 (not expired)
fbcgcteasym000d2                                      B61Ma cn30 (not expired)
cbcgencommon.e                                        B61Ma cn30 (not expired)
cbcgencommon.s                                        B61Ma cn30 (not expired)
bbcbic___slm___                                       B61Ma cn30 (with source) (not expired)
bbcruncommon                                          B61Ma cn30 (with source) (not expired)
obccnv5200                                            B61Ma cn30
obccnv5201                                            B61Ma cn30
obcdmp000                                             B61Ma cn30
obcdmp0100                                            B61Ma cn30
obcdmp9087                                            B61Ma cn30
obcdmp9188                                            B61Ma cn30
obcdmpdllcommon                                       B61Ma cn30
obcgct000                                             B61Ma cn30
obcgct0100                                            B61Ma cn30
obcgct8189                                            B61Ma cn30
obcgct8289                                            B61Ma cn30
obcgct9188                                            B61Ma cn30
obcgcteasy                                            B61Ma cn30
obcgenntdll                                           B61Ma cn30
obcrun8288                                            B61Ma cn30
obcrun90501                                           B61Ma cn30
obcrun90502                                           B61Ma cn30
obcrun90504                                           B61Ma cn30
obcrun90505                                           B61Ma cn30
obcrun90506                                           B61Ma cn30
obcrun90507                                           B61Ma cn30
obcrun90508                                           B61Ma cn30
obcruncommon                                          B61Ma cn30
obcrunconvdll                                         B61Ma cn30
obcrundalload                                         B61Ma cn30
obcrundll0200                                         B61Ma cn30
obcrundllcommon                                       B61Ma cn30
lbcbcdmp9188.05     127                               B61Ma cn30 (not expired)
lbcbcdmp9188.06     127                               B61Ma cn30 (not expired)
lbcbcgct.sour       123                               B61Ma cn30 (not expired)
lbcbcgct.updtblinfo 131                               B61Ma cn30 (not expired)
lbcbcgcteasy.26     109                               B61Ma cn30 (not expired)
lbcbcgcteasy.27     111                               B61Ma cn30 (not expired)
lbcgcteasym000001   119                               B61Ma cn30 (not expired)
Fbccnv4501m00012                                      B61Ma cn30
Fbccnv4502m00012                                      B61Ma cn30
Fbccnv5200m000d2                                      B61Ma cn30
Fbccnv7598m000d2                                      B61Ma cn30
Fbccnv9588m000d2                                      B61Ma cn30
Fbcdmp4220m000d2                                      B61Ma cn30
Fbcdmp9087m000d2                                      B61Ma cn30
Fbcdmp9188m000d2                                      B61Ma cn30
Fbcgct0100m000d2                                      B61Ma cn30
Fbcgct8189m000d2                                      B61Ma cn30
Fbcgcteasym000d2                                      B61Ma cn30
Mbccnvcodalign12                                      B61Ma cn30
Mbccnvnrecords12                                      B61Ma cn30
Mbccnvreport  12                                      B61Ma cn30
Mbccnvtrunutl 12                                      B61Ma cn30
Mbcdmpchecklst12                                      B61Ma cn30
Mbcdmpconvert 12                                      B61Ma cn30
Mbcdmpdebug   12                                      B61Ma cn30
Mbcdmpesetup  12                                      B61Ma cn30
Mbcdmpprocedur12                                      B61Ma cn30
Mbcdmpprocess 12                                      B61Ma cn30
Mbcdmpreports 12                                      B61Ma cn30
Mbcdmpsimulate12                                      B61Ma cn30
Mbcdmputility112                                      B61Ma cn30
Mbcdmputility212                                      B61Ma cn30
Mbcgctconver  12                                      B61Ma cn30
Mbcgctconvert 12                                      B61Ma cn30
Mbcgctmigratio12                                      B61Ma cn30
Mbcgctparam   12                                      B61Ma cn30
Mbcgctpreconv 12                                      B61Ma cn30
Mbcgenconvert 12                                      B61Ma cn30
Mbcgenmigratio12                                      B61Ma cn30
Mbcgenutility112                                      B61Ma cn30
Mbcldrauto    12                                      B61Ma cn30
Mbcldrconvert 12                                      B61Ma cn30
Mbcldrdatavali12                                      B61Ma cn30
Mbcldrmigwizar12                                      B61Ma cn30
Mbcldrprocess 12                                      B61Ma cn30
Mbcldrsetup   12                                      B61Ma cn30
Mbcldrutility 12                                      B61Ma cn30
Mbcldrutility112                                      B61Ma cn30
